diff --git a/doc/src/sgml/func.sgml b/doc/src/sgml/func.sgml
index 7e5bcd9..7f04e504 100644
--- a/doc/src/sgml/func.sgml
+++ b/doc/src/sgml/func.sgml
@@ -11254,6 +11254,25 @@ SELECT NULLIF(value, '(none)') ...
     all are NULL.
    </para>
   </sect2>
+
+  <sect2 id="functions-conditional-implementation">
+   <title>Implementation Notes</title>
+   <para>
+    When a conditional expression depends on the results of aggregate
+    functions in a <command>SELECT</> or <literal>HAVING</> clause, then all
+    the aggregate functions are always evaluated prior to determining which
+    branch the conditional should take.  For example, the following query can
+    cause a division-by-zero error despite only using division in a branch
+    that requires positive values:
+
+<programlisting>
+SELECT CASE WHEN min(employees) > 0
+            THEN average(expenses / employees)
+       END
+    FROM departments;
+</programlisting>
+   </para>
+  </sect2>
  </sect1>
 
  <sect1 id="functions-array">
diff --git a/doc/src/sgml/ref/select.sgml b/doc/src/sgml/ref/select.sgml
index 473939a..36f4941 100644
--- a/doc/src/sgml/ref/select.sgml
+++ b/doc/src/sgml/ref/select.sgml
@@ -111,9 +111,11 @@ TABLE [ ONLY ] <replaceable class="parameter">table_name</replaceable> [ * ]
      <para>
       If the <literal>GROUP BY</literal> clause is specified, the
       output is combined into groups of rows that match on one or more
-      values.  If the <literal>HAVING</literal> clause is present, it
-      eliminates groups that do not satisfy the given condition.  (See
-      <xref linkend="sql-groupby" endterm="sql-groupby-title"> and
+      values.  All aggregate functions and their argument expressions
+      in the <command>SELECT</> and <literal>HAVING</> are evaluated.
+      If the <literal>HAVING</literal> clause is present, it eliminates
+      groups that do not satisfy the given condition.  (See
+      <xref linkend="sql-groupby" endterm="sql-groupby-title">, and
       <xref linkend="sql-having" endterm="sql-having-title"> below.)
      </para>
     </listitem>
